==> switchyard-component-jca-0.6.0.Final-sources.jar: org/switchyard/component/jca/selector/CCIOperationSelectorFactory.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2009, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.switchyard.component.jca.selector;

import org.switchyard.component.common.selector.OperationSelector;
import org.switchyard.component.common.selector.OperationSelectorFactory;
import org.switchyard.component.jca.composer.MappedRecordBindingData;

/**
 * An example of OperationSelectorFactory implementation for CCI MappedRecord.
 */
public class CCIOperationSelectorFactory extends OperationSelectorFactory<MappedRecordBindingData> {

    @Override
    public Class<MappedRecordBindingData> getTargetClass() {
        return MappedRecordBindingData.class;
    }

    @Override
    public Class<? extends OperationSelector<MappedRecordBindingData>> getDefaultOperationSelectorClass() {
        return CCIOperationSelector.class;
    }

}

==> switchyard-component-jca-0.7.0.Final-sources.jar: org/switchyard/component/jca/selector/CCIOperationSelectorFactory.java <==
/*
 * JBoss, Home of Professional Open Source Copyright 2009, Red Hat Middleware
 * LLC, and individual contributors by the @authors tag. See the copyright.txt
 * in the distribution for a full listing of individual contributors.
 * 
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this software; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA, or see the FSF
 * site: http://www.fsf.org.
 */
package org.switchyard.component.jca.selector;

import org.switchyard.component.common.selector.OperationSelectorFactory;
import org.switchyard.component.jca.composer.MappedRecordBindingData;
import org.switchyard.selector.OperationSelector;

/**
 * An example of OperationSelectorFactory implementation for CCI MappedRecord.
 */
public class CCIOperationSelectorFactory extends OperationSelectorFactory<MappedRecordBindingData> {

    @Override
    public Class<MappedRecordBindingData> getTargetClass() {
        return MappedRecordBindingData.class;
    }

    @Override
    public Class<? extends OperationSelector<MappedRecordBindingData>> getDefaultOperationSelectorClass() {
        return CCIOperationSelector.class;
    }

}
